@@ -91,8 +91,8 @@ extern struct SyntaxDef      PopupFuncSyntax;
 #define FUNC_ID_START           F_NOP   /* 0 */
 #define FUNC_ID_END           	F_FUNCTIONS_NUM
 
-extern struct TermDef FuncTerms[F_FUNCTIONS_NUM + 1];
-extern struct SyntaxDef FuncSyntax;
+extern struct SyntaxDef *pFuncSyntax;
+extern struct SyntaxDef DummyFuncSyntax;
 
 /* used in some "special" function to correctly process trailing function definition */
 unsigned long TrailingFuncSpecial (struct ConfigDef * config, struct FreeStorageElem ** storage, int skip_tokens);
@@ -209,6 +209,11 @@ struct FunctionData     *String2Func ( const char *string, struct FunctionData *
 
 #define CONFIG_ID_END					(CONFIG_SUBOPTIONS_IDS+23)
 
+
+/* must call this one to fix all the pointers referencing libAfterStep */
+void LinkAfterStepConfig();
+
+
 /***************************************************************************/
 /*                        Base file pasring definitions                    */
 /***************************************************************************/
@@ -404,10 +409,16 @@ struct FreeStorageElem **MyStyleDefs2FreeStorage (struct SyntaxDef * syntax, str
 #define MYFRAME_TitleFCM_ID             (MYFRAME_ID_START+37)
 #define MYFRAME_TitleUCM_ID             (MYFRAME_ID_START+38)
 #define MYFRAME_TitleSCM_ID             (MYFRAME_ID_START+39)
-#define MYFRAME_Inherit_ID              (MYFRAME_ID_START+40)
-#define MYFRAME_DONE_ID                 (MYFRAME_ID_START+41)
+#define MYFRAME_TitleFHue_ID			(MYFRAME_ID_START+40)
+#define MYFRAME_TitleUHue_ID			(MYFRAME_ID_START+41)
+#define MYFRAME_TitleSHue_ID			(MYFRAME_ID_START+42)
+#define MYFRAME_TitleFSat_ID			(MYFRAME_ID_START+43)
+#define MYFRAME_TitleUSat_ID			(MYFRAME_ID_START+44)
+#define MYFRAME_TitleSSat_ID			(MYFRAME_ID_START+45)
+#define MYFRAME_Inherit_ID              (MYFRAME_ID_START+46)
+#define MYFRAME_DONE_ID                 (MYFRAME_ID_START+47)
 
-#define MYFRAME_TitleBackground_ID_START	(MYFRAME_ID_START+42)
+#define MYFRAME_TitleBackground_ID_START	(MYFRAME_ID_START+48)
 #define MYFRAME_LeftBtnBackground_ID		(MYFRAME_TitleBackground_ID_START+MYFRAME_TITLE_BACK_LBTN	)
 #define MYFRAME_LeftSpacerBackground_ID 	(MYFRAME_TitleBackground_ID_START+MYFRAME_TITLE_BACK_LSPACER)
 #define MYFRAME_LTitleSpacerBackground_ID 	(MYFRAME_TitleBackground_ID_START+MYFRAME_TITLE_BACK_LTITLE_SPACER)
@@ -431,7 +442,10 @@ struct FreeStorageElem **MyStyleDefs2FreeStorage (struct SyntaxDef * syntax, str
 #define MYFRAME_LeftTitlebarLayout_ID			(MYFRAME_TitleBackgroundAlign_ID_END+2)
 #define MYFRAME_RightTitlebarLayout_ID			(MYFRAME_TitleBackgroundAlign_ID_END+3)
 
-#define MYFRAME_NoBorder_ID             		(MYFRAME_TitleBackgroundAlign_ID_END+4) 
+#define MYFRAME_LeftBtnAlign_ID					(MYFRAME_TitleBackgroundAlign_ID_END+4)
+#define MYFRAME_RightBtnAlign_ID				(MYFRAME_TitleBackgroundAlign_ID_END+5)
+
+#define MYFRAME_NoBorder_ID             		(MYFRAME_TitleBackgroundAlign_ID_END+6) 
 #define MYFRAME_AllowBorder_ID             		(MYFRAME_NoBorder_ID+1) 
 
 #define MYFRAME_ID_END      (MYFRAME_ID_START+128)
@@ -558,8 +572,11 @@ typedef struct MyFrameDefinition
     ASFlagType   title_align ;
 	ASFlagType   title_backs_align[MYFRAME_TITLE_BACKS];
     int          title_fcm, title_ucm, title_scm;
+	char 		*title_fhue, *title_uhue, *title_shue; 
+	int          title_fsat, title_usat, title_ssat;
     ASFlagType   condense_titlebar ;
 	unsigned long left_layout, right_layout ;
+	ASFlagType   left_btn_align, right_btn_align ;
 
 	ASFlagType   flags ;
 	ASFlagType   set_flags ;
@@ -722,6 +739,7 @@ typedef struct
   {
     int    rows, columns;
     ASGeometry geometry, icon_geometry;
+	int ndesks ;
     char **labels;
     char **styles;
     int    align;
